{% extends "admin/change_form.html" %}
{% load url from future %}

{% block extrahead %}{{ block.super }}
<script type="text/javascript">
    var admin_url = '{% url "admin:index" %}';
    var static_url = '{{ STATIC_URL }}';
    var get_ctype_url = '{% url "get_ctype_details" %}';
</script>
<script type="text/javascript" src="{{ STATIC_URL }}hero_slider/js/generic_raw_id_field.js"></script>
{% endblock %}
